/*
 * System Interface Library for games
 * Copyright (c) 2007-2014 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * src/sysdep/psp/mutex.c: Mutex routines for the PSP.
 */

#define IN_SYSDEP

#include "src/base.h"
#include "src/math.h"
#include "src/sysdep.h"

/*************************************************************************/
/************************** Interface routines ***************************/
/*************************************************************************/

SysMutexID sys_mutex_create(int initially_locked)
{
    /* The PSP doesn't have native mutexes, so we fake them with semaphores. */
    const int initial_value = (initially_locked ? 0 : 1);
    return sys_semaphore_create(initial_value, 1);
}

/*-----------------------------------------------------------------------*/

void sys_mutex_destroy(SysMutexID mutex)
{
    sys_semaphore_destroy(mutex);
}

/*-----------------------------------------------------------------------*/

void sys_mutex_lock(SysMutexID mutex)
{
    sys_semaphore_wait(mutex);
}

/*-----------------------------------------------------------------------*/

int sys_mutex_lock_timeout(SysMutexID mutex, float timeout)
{
    return sys_semaphore_wait_timeout(mutex, timeout);
}

/*-----------------------------------------------------------------------*/

void sys_mutex_unlock(SysMutexID mutex)
{
    sys_semaphore_signal(mutex);
}

/*************************************************************************/
/*************************************************************************/

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
